@@ -216,15 +216,14 @@ var jsonScenarios = []formatScenario{
 		scenarioType:   "encode",
 	},
 	{
-		description:    "Roundtrip NDJSON",
-		subdescription: "Unfortunately the json encoder strips leading spaces of values.",
-		input:          sampleNdJson,
-		expected:       expectedRoundTripSampleNdJson,
-		scenarioType:   "roundtrip-ndjson",
+		description:  "Roundtrip JSON Lines / NDJSON",
+		input:        sampleNdJson,
+		expected:     expectedRoundTripSampleNdJson,
+		scenarioType: "roundtrip-ndjson",
 	},
 	{
 		description:    "Roundtrip multi-document JSON",
-		subdescription: "The NDJSON parser can also handle multiple multi-line json documents in a single file!",
+		subdescription: "The parser can also handle multiple multi-line json documents in a single file (despite this not being in the JSON Lines / NDJSON spec). Typically you would have one entire JSON document per line, but the parser also supports multiple multi-line json documents",
 		input:          sampleMultiLineJson,
 		expected:       roundTripMultiLineJson,
 		scenarioType:   "roundtrip-multi",
@@ -246,13 +245,13 @@ var jsonScenarios = []formatScenario{
 		scenarioType:   "roundtrip-ndjson",
 	},
 	{
-		description:  "Decode NDJSON",
+		description:  "Decode JSON Lines / NDJSON",
 		input:        sampleNdJson,
 		expected:     expectedNdJsonYaml,
 		scenarioType: "decode-ndjson",
 	},
 	{
-		description:  "Decode NDJSON, maintain key order",
+		description:  "Decode JSON Lines / NDJSON, maintain key order",
 		skipDoc:      true,
 		input:        sampleNdJsonKey,
 		expected:     expectedJsonKeysInOrder,
