@@ -16,6 +16,19 @@ name = "Tom Preston-Werner"
 age = 36
 `
 
+var tableArrayBeforeOwners = `
+[[owner.addresses]]
+street = "first street"
+
+[owner]
+name = "Tom Preston-Werner"
+`
+var expectedTableArrayBeforeOwners = `owner:
+  addresses:
+    - street: first street
+  name: Tom Preston-Werner
+`
+
 var sampleTableExpected = `var: x
 owner:
   contact:
@@ -74,6 +87,13 @@ var tomlScenarios = []formatScenario{
 		expected:     "",
 		scenarioType: "decode",
 	},
+	{
+		skipDoc:      true,
+		description:  "table array before owners",
+		input:        tableArrayBeforeOwners,
+		expected:     expectedTableArrayBeforeOwners,
+		scenarioType: "decode",
+	},
 	{
 		skipDoc:      true,
 		description:  "datetime",
